@@ -246,38 +246,44 @@ struct hostrange_cmd_args
 #define IPMI_DEVICE_OPENIPMI_STR "openipmi"
 #define IPMI_DEVICE_SUNBMC_STR   "sunbmc"
 
-#define IPMI_TOOL_WORKAROUND_FLAGS_DEFAULT                     0x00000000
-#define IPMI_TOOL_WORKAROUND_FLAGS_ACCEPT_SESSION_ID_ZERO      0x00000001
-#define IPMI_TOOL_WORKAROUND_FLAGS_FORCE_PERMSG_AUTHENTICATION 0x00000002
-#define IPMI_TOOL_WORKAROUND_FLAGS_CHECK_UNEXPECTED_AUTHCODE   0x00000004
-#define IPMI_TOOL_WORKAROUND_FLAGS_BIG_ENDIAN_SEQUENCE_NUMBER  0x00000008
-#define IPMI_TOOL_WORKAROUND_FLAGS_AUTHENTICATION_CAPABILITIES 0x00000010
-#define IPMI_TOOL_WORKAROUND_FLAGS_INTEL_2_0_SESSION           0x00000020
-#define IPMI_TOOL_WORKAROUND_FLAGS_SUPERMICRO_2_0_SESSION      0x00000040
-#define IPMI_TOOL_WORKAROUND_FLAGS_SUN_2_0_SESSION             0x00000080
-#define IPMI_TOOL_WORKAROUND_FLAGS_OPEN_SESSION_PRIVILEGE      0x00000100
+#define IPMI_TOOL_WORKAROUND_FLAGS_DEFAULT                         0x00000000
+#define IPMI_TOOL_WORKAROUND_FLAGS_ACCEPT_SESSION_ID_ZERO          0x00000001
+#define IPMI_TOOL_WORKAROUND_FLAGS_FORCE_PERMSG_AUTHENTICATION     0x00000002
+#define IPMI_TOOL_WORKAROUND_FLAGS_CHECK_UNEXPECTED_AUTHCODE       0x00000004
+#define IPMI_TOOL_WORKAROUND_FLAGS_BIG_ENDIAN_SEQUENCE_NUMBER      0x00000008
+#define IPMI_TOOL_WORKAROUND_FLAGS_AUTHENTICATION_CAPABILITIES     0x00000010
+#define IPMI_TOOL_WORKAROUND_FLAGS_INTEL_2_0_SESSION               0x00000020
+#define IPMI_TOOL_WORKAROUND_FLAGS_SUPERMICRO_2_0_SESSION          0x00000040
+#define IPMI_TOOL_WORKAROUND_FLAGS_SUN_2_0_SESSION                 0x00000080
+#define IPMI_TOOL_WORKAROUND_FLAGS_OPEN_SESSION_PRIVILEGE          0x00000100
+#define IPMI_TOOL_WORKAROUND_FLAGS_NON_EMPTY_INTEGRITY_CHECK_VALUE 0x00000200
 
-#define IPMI_TOOL_WORKAROUND_FLAGS_ACCEPT_SESSION_ID_ZERO_STR      "idzero"
-#define IPMI_TOOL_WORKAROUND_FLAGS_FORCE_PERMSG_AUTHENTICATION_STR "forcepermsg"
-#define IPMI_TOOL_WORKAROUND_FLAGS_CHECK_UNEXPECTED_AUTHCODE_STR   "unexpectedauth"
-#define IPMI_TOOL_WORKAROUND_FLAGS_BIG_ENDIAN_SEQUENCE_NUMBER_STR  "endianseq"
-#define IPMI_TOOL_WORKAROUND_FLAGS_AUTHENTICATION_CAPABILITIES_STR "authcap"
-#define IPMI_TOOL_WORKAROUND_FLAGS_INTEL_2_0_SESSION_STR           "intel20"
-#define IPMI_TOOL_WORKAROUND_FLAGS_SUPERMICRO_2_0_SESSION_STR      "supermicro20"
-#define IPMI_TOOL_WORKAROUND_FLAGS_SUN_2_0_SESSION_STR             "sun20"
-#define IPMI_TOOL_WORKAROUND_FLAGS_OPEN_SESSION_PRIVILEGE_STR      "opensesspriv"
+#define IPMI_TOOL_WORKAROUND_FLAGS_ACCEPT_SESSION_ID_ZERO_STR          "idzero"
+#define IPMI_TOOL_WORKAROUND_FLAGS_FORCE_PERMSG_AUTHENTICATION_STR     "forcepermsg"
+#define IPMI_TOOL_WORKAROUND_FLAGS_CHECK_UNEXPECTED_AUTHCODE_STR       "unexpectedauth"
+#define IPMI_TOOL_WORKAROUND_FLAGS_BIG_ENDIAN_SEQUENCE_NUMBER_STR      "endianseq"
+#define IPMI_TOOL_WORKAROUND_FLAGS_AUTHENTICATION_CAPABILITIES_STR     "authcap"
+#define IPMI_TOOL_WORKAROUND_FLAGS_INTEL_2_0_SESSION_STR               "intel20"
+#define IPMI_TOOL_WORKAROUND_FLAGS_SUPERMICRO_2_0_SESSION_STR          "supermicro20"
+#define IPMI_TOOL_WORKAROUND_FLAGS_SUN_2_0_SESSION_STR                 "sun20"
+#define IPMI_TOOL_WORKAROUND_FLAGS_OPEN_SESSION_PRIVILEGE_STR          "opensesspriv"
+#define IPMI_TOOL_WORKAROUND_FLAGS_NON_EMPTY_INTEGRITY_CHECK_VALUE_STR "integritycheckvalue"
 
 #define IPMI_TOOL_SPECIFIC_WORKAROUND_FLAGS_IGNORE_SOL_PAYLOAD_SIZE     0x00000001
 #define IPMI_TOOL_SPECIFIC_WORKAROUND_FLAGS_IGNORE_SOL_PORT             0x00000002
 #define IPMI_TOOL_SPECIFIC_WORKAROUND_FLAGS_SKIP_SOL_ACTIVATION_STATUS  0x00000004
 #define IPMI_TOOL_SPECIFIC_WORKAROUND_FLAGS_SKIP_CHECKS                 0x00000008
 #define IPMI_TOOL_SPECIFIC_WORKAROUND_FLAGS_ASSUME_SYSTEM_EVENT         0x00000010
+#define IPMI_TOOL_SPECIFIC_WORKAROUND_FLAGS_SLOW_COMMIT                 0x00000020
+#define IPMI_TOOL_SPECIFIC_WORKAROUND_FLAGS_IGNORE_STATE_FLAG           0x00000040
 
 #define IPMI_TOOL_SPECIFIC_WORKAROUND_FLAGS_IGNORE_SOL_PAYLOAD_SIZE_STR    "solpayloadsize"
 #define IPMI_TOOL_SPECIFIC_WORKAROUND_FLAGS_IGNORE_SOL_PORT_STR            "solport"
 #define IPMI_TOOL_SPECIFIC_WORKAROUND_FLAGS_SKIP_SOL_ACTIVATION_STATUS_STR "solstatus"
 #define IPMI_TOOL_SPECIFIC_WORKAROUND_FLAGS_SKIP_CHECKS_STR                "skipchecks"
 #define IPMI_TOOL_SPECIFIC_WORKAROUND_FLAGS_ASSUME_SYSTEM_EVENT_STR        "assumesystemevent"
+#define IPMI_TOOL_SPECIFIC_WORKAROUND_FLAGS_SLOW_COMMIT_STR                "slowcommit"
+#define IPMI_TOOL_SPECIFIC_WORKAROUND_FLAGS_IGNORE_STATE_FLAG_STR          "ignorestateflag"
 
 #define IPMI_AUTHENTICATION_TYPE_NONE_STR                               "none"
 #define IPMI_AUTHENTICATION_TYPE_STRAIGHT_PASSWORD_KEY_STR              "straight_password_key"
