@@ -1,7 +1,7 @@
 /*****************************************************************************\
- *  $Id: ipmi-fru.h,v 1.14 2009/05/22 02:33:39 chu11 Exp $
+ *  $Id: ipmi-fru.h,v 1.14.4.2 2009/12/23 21:24:05 chu11 Exp $
  *****************************************************************************
- *  Copyright (C) 2007-2009 Lawrence Livermore National Security, LLC.
+ *  Copyright (C) 2007-2010 Lawrence Livermore National Security, LLC.
  *  Copyright (C) 2007 The Regents of the University of California.
  *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
  *  Written by Albert Chu <chu11@llnl.gov>
@@ -32,6 +32,7 @@
 #include <freeipmi/freeipmi.h>
 
 #include "tool-cmdline-common.h"
+#include "tool-oem-common.h"
 #include "pstdout.h"
 
 enum ipmi_sel_argp_option_keys
@@ -69,8 +70,7 @@ typedef struct ipmi_fru_state_data
   ipmi_fru_parse_ctx_t fru_parse_ctx;
   ipmi_sdr_cache_ctx_t sdr_cache_ctx;
   ipmi_sdr_parse_ctx_t sdr_parse_ctx;
-  uint32_t manufacturer_id;
-  uint16_t product_id;
+  struct ipmi_oem_data oem_data;
 } ipmi_fru_state_data_t;
 
 #endif
