@@ -183,8 +183,6 @@
 /* 0x0F-0xFE - Reserved */
 #define IPMI_QUANTA_PROCESSOR_TYPE_NO_CPU_PRESENT 0xFF
 
-#if 0
-/* dangerous - truly nukes settings, including SDR */
 int
 ipmi_oem_quanta_reset_to_defaults (ipmi_oem_state_data_t *state_data)
 {
@@ -343,7 +341,6 @@ ipmi_oem_quanta_reset_to_defaults (ipmi_oem_state_data_t *state_data)
  cleanup:
   return (rv);
 }
-#endif
 
 int
 ipmi_oem_quanta_get_processor_information (ipmi_oem_state_data_t *state_data)
