@@ -1,5 +1,5 @@
 /*****************************************************************************\
- *  $Id: ipmiconsole_checks.c,v 1.39.4.4 2010/06/11 15:56:52 chu11 Exp $
+ *  $Id: ipmiconsole_checks.c,v 1.39.4.6 2010/07/13 23:51:34 chu11 Exp $
  *****************************************************************************
  *  Copyright (C) 2007-2010 Lawrence Livermore National Security, LLC.
  *  Copyright (C) 2006-2007 The Regents of the University of California.
@@ -575,14 +575,32 @@ ipmiconsole_check_open_session_response_privilege (ipmiconsole_ctx_t c, ipmicons
     }
   else
     {
-      if ((rv = ipmi_check_open_session_maximum_privilege (c->config.privilege_level,
-                                                           c->connection.obj_open_session_response)) < 0)
-        {
-          IPMICONSOLE_CTX_DEBUG (c, ("ipmi_check_open_session_maximum_privilege: %s",
-                                     strerror (errno)));
-          ipmiconsole_ctx_set_errnum (c, IPMICONSOLE_ERR_INTERNAL_ERROR);
-          return (-1);
-        }
+      /* IPMI Workaround
+       *
+       * Discovered on Supermicro X8DTG
+       *
+       * The maximum privilege level returned may be incorrect, leading to
+       * a possible IPMI_ERR_PRIVILEGE_LEVEL_CANNOT_BE_OBTAINED errors and
+       * related issues with SIK key generation.
+       *
+       * In order to workaround this, we skip the following check and
+       * use the "maximum_privilege_level" for generating the SIK key
+       * below.  Any privilege level issues will be caught by setting
+       * the session privilege level later on.
+       */
+      if (!(c->config.workaround_flags & IPMICONSOLE_WORKAROUND_OPEN_SESSION_PRIVILEGE))
+	{
+	  if ((rv = ipmi_check_open_session_maximum_privilege (c->config.privilege_level,
+							       c->connection.obj_open_session_response)) < 0)
+	    {
+	      IPMICONSOLE_CTX_DEBUG (c, ("ipmi_check_open_session_maximum_privilege: %s",
+					 strerror (errno)));
+	      ipmiconsole_ctx_set_errnum (c, IPMICONSOLE_ERR_INTERNAL_ERROR);
+	      return (-1);
+	    }
+	}
+      else
+	rv = 1;
     }
 
   if (!rv)
@@ -897,7 +915,8 @@ ipmiconsole_check_rakp_4_integrity_check_value (ipmiconsole_ctx_t c, ipmiconsole
 
   /* IPMI Workaround (achu)
    *
-   * Discovered on Supermicro X8DTG, Intel S5500WBV/Penguin Relion 700
+   * Discovered on Supermicro X8DTG, Supermicro X8DTU, Intel
+   * S5500WBV/Penguin Relion 700
    *
    * For whatever reason, with cipher suite 0, the RAKP 4 response
    * returns with an Integrity Check Value when it should be empty.
