@@ -1,7 +1,7 @@
 /*****************************************************************************\
- *  $Id: ipmiconsole_engine.c,v 1.90 2009/10/22 20:20:00 chu11 Exp $
+ *  $Id: ipmiconsole_engine.c,v 1.90.4.6 2009/12/23 21:24:10 chu11 Exp $
  *****************************************************************************
- *  Copyright (C) 2007-2009 Lawrence Livermore National Security, LLC.
+ *  Copyright (C) 2007-2010 Lawrence Livermore National Security, LLC.
  *  Copyright (C) 2006-2007 The Regents of the University of California.
  *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
  *  Written by Albert Chu <chu11@llnl.gov>
@@ -198,7 +198,10 @@ ipmiconsole_engine_setup (unsigned int thread_count)
 
   if (ipmi_rmcpplus_init () < 0)
     {
-      IPMICONSOLE_DEBUG (("ipmi_crypt_init: %s", strerror (errno)));
+      if (errno == EPERM)
+        IPMICONSOLE_DEBUG (("ipmi_rmcpplus_init: incompatible crypto library"));
+      else
+        IPMICONSOLE_DEBUG (("ipmi_rmcpplus_init: %s", strerror (errno)));
       goto cleanup;
     }
 
@@ -467,6 +470,43 @@ _ipmi_recvfrom (ipmiconsole_ctx_t c)
                                &fromlen);
     } while (len < 0 && errno == EINTR);
 
+  /* achu & hliebig:
+   *
+   * Premise from ipmitool (http://ipmitool.sourceforge.net/)
+   *
+   * On some OSes (it seems Unixes), the behavior is to not return
+   * port denied errors up to the client for UDP responses (i.e. you
+   * need to timeout).  But on some OSes (it seems Windows), the
+   * behavior is to return port denied errors up to the user for UDP
+   * responses via ECONNRESET or ECONNREFUSED.
+   *
+   * If this were just the case, we could return or handle errors
+   * properly and move on.  However, it's not the case.
+   *
+   * According to Ipmitool, on some motherboards, both the OS and the
+   * BMC are capable of responding to an IPMI request.  That means you
+   * can get an ECONNRESET or ECONNREFUSED, then later on, get your
+   * real IPMI response.
+   *
+   * Our solution is copied from Ipmitool, we'll ignore some specific
+   * errors and try to read again.
+   *
+   * If the ECONNREFUSED or ECONNRESET is from the OS, but we will get
+   * an IPMI response later, the recvfrom later on gets the packet we
+   * want.
+   *
+   * If the ECONNREFUSED or ECONNRESET is from the OS but there is no
+   * BMC (or IPMI disabled, etc.), just do the recvfrom again to
+   * eventually get a timeout, which is the behavior we'd like.
+   */
+  if (len < 0
+      && (errno == ECONNRESET
+          || errno == ECONNREFUSED))
+    {
+      IPMICONSOLE_CTX_DEBUG (c, ("ipmi_lan_recvfrom: connection refused: %s", strerror (errno)));
+      return (0);
+    }
+
   if (len < 0)
     {
       IPMICONSOLE_CTX_DEBUG (c, ("ipmi_lan_recvfrom: %s", strerror (errno)));
@@ -988,9 +1028,13 @@ _ipmiconsole_engine (void *arg)
           if (poll_data.pfds[i*3].revents & POLLERR)
             {
               IPMICONSOLE_CTX_DEBUG (poll_data.pfds_ctxs[i], ("POLLERR"));
-              ipmiconsole_ctx_set_errnum (poll_data.pfds_ctxs[i], IPMICONSOLE_ERR_INTERNAL_ERROR);
-              poll_data.pfds_ctxs[i]->session.close_session_flag++;
-              continue;
+              /* See comments in _ipmi_recvfrom() regarding ECONNRESET/ECONNREFUSED */
+              if (_ipmi_recvfrom (poll_data.pfds_ctxs[i]) < 0)
+                {
+                  ipmiconsole_ctx_set_errnum (poll_data.pfds_ctxs[i], IPMICONSOLE_ERR_SYSTEM_ERROR);
+                  poll_data.pfds_ctxs[i]->session.close_session_flag++;
+                  continue;
+                }
             }
           if (!poll_data.pfds_ctxs[i]->session.close_session_flag)
             {
