@@ -1,5 +1,5 @@
 /*****************************************************************************\
- *  $Id: ipmipower_powercmd.c,v 1.196.2.6 2010/06/11 15:56:53 chu11 Exp $
+ *  $Id: ipmipower_powercmd.c,v 1.196.2.8 2010/07/13 23:51:35 chu11 Exp $
  *****************************************************************************
  *  Copyright (C) 2007-2010 Lawrence Livermore National Security, LLC.
  *  Copyright (C) 2003-2007 The Regents of the University of California.
@@ -274,8 +274,8 @@ ipmipower_powercmd_queue (power_cmd_t cmd, struct ipmipower_connection *ic)
       /* IPMI Workaround (achu)
        *
        * Discovered on Sun Fire 4100, Inventec 5441/Dell Xanadu II,
-       * Supermicro X8DTH, Supermicro X8DTG, Intel S5500WBV/Penguin
-       * Relion 700
+       * Supermicro X8DTH, Supermicro X8DTG, Supermicro X8DTU, Intel
+       * S5500WBV/Penguin Relion 700
        *
        * The remote BMC incorrectly calculates keys using the privilege
        * specified in the open session stage rather than the privilege
@@ -1583,6 +1583,8 @@ _calculate_cipher_keys (ipmipower_powercmd_t ip)
   char *password;
   unsigned int password_len;
   void *k_g;
+  uint8_t session_keys_privilege;
+  uint64_t val;
 
   assert (ip);
   assert (ip->protocol_state == PROTOCOL_STATE_RAKP_MESSAGE_1_SENT);
@@ -1643,6 +1645,32 @@ _calculate_cipher_keys (ipmipower_powercmd_t ip)
       exit (1);
     }
 
+  /* IPMI Workaround (achu)
+   *
+   * Discovered on Supermicro X8DTG
+   *
+   * The maximum privilege level returned from the Open Session
+   * Privilege Response may be incorrect, leading to issues with SIK
+   * key generation.
+   *
+   * In order to workaround this, we use the "maximum_privilege_level"
+   * for generating the SIK key below.
+   */
+  if (cmd_args.common.workaround_flags & IPMI_TOOL_WORKAROUND_FLAGS_OPEN_SESSION_PRIVILEGE)
+    {
+      if (FIID_OBJ_GET (ip->obj_open_session_res,
+			"maximum_privilege_level",
+			&val) < 0)
+	{
+	  IPMIPOWER_ERROR (("FIID_OBJ_GET: 'maximum_privilege_level': %s",
+			    fiid_obj_errormsg (ip->obj_open_session_res)));
+	  exit (1);
+	}
+      session_keys_privilege = val;
+    }
+  else
+    session_keys_privilege = cmd_args.common.privilege_level;
+
   if (ipmi_calculate_rmcpplus_session_keys (ip->authentication_algorithm,
                                             ip->integrity_algorithm,
                                             ip->confidentiality_algorithm,
@@ -1655,7 +1683,7 @@ _calculate_cipher_keys (ipmipower_powercmd_t ip)
                                             managed_system_random_number,
                                             managed_system_random_number_len,
                                             ip->name_only_lookup,
-                                            cmd_args.common.privilege_level,
+					    session_keys_privilege,
                                             username,
                                             username_len,
                                             &(ip->sik_key_ptr),
