@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2003-2009 FreeIPMI Core Team
+   Copyright (C) 2003-2010 FreeIPMI Core Team
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -420,7 +420,7 @@ int fill_cmd_send_message (uint8_t channel_number,
                            uint8_t message_encryption,
                            uint8_t tracking_operation,
                            const void *message_data,
-                           uint32_t message_data_len,
+                           unsigned int message_data_len,
                            fiid_obj_t obj_cmd_rq);
 
 int fill_cmd_read_event_message_buffer (fiid_obj_t obj_cmd_rq);
